@@ -19,8 +19,6 @@ def imports() -> str:
         "from __future__ import annotations",
         "from enum import Enum",
         "from datetime import datetime, date",
-        "import asyncio",
-        "from pathlib import Path",
         "from pydantic import BaseModel, Field",
         f"from dgraph_orm import {ORM_MODEL_NAME}, Node, GQLException",
         f"from dgraph_orm.ACL.client import DgraphClient",
@@ -897,16 +895,6 @@ async def login_client() -> None:
         password="{app_config['password']}",
         namespace={app_config['namespace']},
     )
-try:
-    loop = asyncio.get_running_loop()
-except RuntimeError:
-    loop = None
-
-if loop and loop.is_running():
-    tsk = loop.create_task(login_client())
-    tsk.add_done_callback(lambda t: print(f"Done logging in for {{Path(__file__).name}}"))
-else:
-    asyncio.run(login_client())
     """
     return format_str(s, mode=FileMode())
 
